@@ -1,5 +1,5 @@
 #  Pyrogram - Telegram MTProto API Client Library for Python
-#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
+#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
 #
 #  This file is part of Pyrogram.
 #
@@ -17,13 +17,14 @@
 #  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
-from typing import Union, BinaryIO
+from typing import Union, BinaryIO, Optional
 
 from pyrogram import StopTransmission
 from pyrogram import raw
 from pyrogram import types
 from pyrogram import utils
 from pyrogram.errors import FilePartMissing
+from pyrogram.file_id import FileType
 from pyrogram.scaffold import Scaffold
 
 
@@ -32,7 +33,6 @@ class SendVideoNote(Scaffold):
         self,
         chat_id: Union[int, str],
         video_note: Union[str, BinaryIO],
-        file_ref: str = None,
         duration: int = 0,
         length: int = 1,
         thumb: Union[str, BinaryIO] = None,
@@ -47,7 +47,7 @@ class SendVideoNote(Scaffold):
         ] = None,
         progress: callable = None,
         progress_args: tuple = ()
-    ) -> Union["types.Message", None]:
+    ) -> Optional["types.Message"]:
         """Send video messages.
 
         Parameters:
@@ -63,10 +63,6 @@ class SendVideoNote(Scaffold):
                 pass a binary file-like object with its attribute ".name" set for in-memory uploads.
                 Sending video notes by a URL is currently unsupported.
 
-            file_ref (``str``, *optional*):
-                A valid file reference obtained by a recently fetched media message.
-                To be used in combination with a file id in case a file reference is needed.
-
             duration (``int``, *optional*):
                 Duration of sent video in seconds.
 
@@ -150,7 +146,7 @@ class SendVideoNote(Scaffold):
                         ]
                     )
                 else:
-                    media = utils.get_input_media_from_file_id(video_note, file_ref, 13)
+                    media = utils.get_input_media_from_file_id(video_note, FileType.VIDEO_NOTE)
             else:
                 thumb = await self.save_file(thumb)
                 file = await self.save_file(video_note, progress=progress, progress_args=progress_args)
